@@ -23,15 +23,13 @@ require 'selenium/webdriver/common/proxy'
 require 'selenium/webdriver/common/log_entry'
 require 'selenium/webdriver/common/file_reaper'
 require 'selenium/webdriver/common/service'
+require 'selenium/webdriver/common/service_manager'
 require 'selenium/webdriver/common/socket_lock'
 require 'selenium/webdriver/common/socket_poller'
 require 'selenium/webdriver/common/port_prober'
 require 'selenium/webdriver/common/zipper'
 require 'selenium/webdriver/common/wait'
 require 'selenium/webdriver/common/alert'
-require 'selenium/webdriver/common/mouse'
-require 'selenium/webdriver/common/keyboard'
-require 'selenium/webdriver/common/touch_screen'
 require 'selenium/webdriver/common/target_locator'
 require 'selenium/webdriver/common/navigation'
 require 'selenium/webdriver/common/timeouts'
@@ -39,39 +37,61 @@ require 'selenium/webdriver/common/window'
 require 'selenium/webdriver/common/logger'
 require 'selenium/webdriver/common/logs'
 require 'selenium/webdriver/common/manager'
-require 'selenium/webdriver/common/w3c_manager'
 require 'selenium/webdriver/common/search_context'
-require 'selenium/webdriver/common/action_builder'
+require 'selenium/webdriver/common/interactions/interaction'
+require 'selenium/webdriver/common/interactions/interactions'
+require 'selenium/webdriver/common/interactions/pointer_event_properties'
+require 'selenium/webdriver/common/interactions/pointer_cancel'
+require 'selenium/webdriver/common/interactions/pointer_move'
+require 'selenium/webdriver/common/interactions/pointer_press'
+require 'selenium/webdriver/common/interactions/typing_interaction'
+require 'selenium/webdriver/common/interactions/pause'
 require 'selenium/webdriver/common/interactions/key_actions'
 require 'selenium/webdriver/common/interactions/pointer_actions'
-require 'selenium/webdriver/common/w3c_action_builder'
-require 'selenium/webdriver/common/touch_action_builder'
+require 'selenium/webdriver/common/interactions/input_device'
+require 'selenium/webdriver/common/interactions/none_input'
+require 'selenium/webdriver/common/interactions/key_input'
+require 'selenium/webdriver/common/interactions/pointer_input'
+require 'selenium/webdriver/common/interactions/scroll'
+require 'selenium/webdriver/common/interactions/wheel_input'
+require 'selenium/webdriver/common/interactions/scroll_origin'
+require 'selenium/webdriver/common/interactions/wheel_actions'
+require 'selenium/webdriver/common/action_builder'
+require 'selenium/webdriver/common/virtual_authenticator/credential'
+require 'selenium/webdriver/common/virtual_authenticator/virtual_authenticator_options'
+require 'selenium/webdriver/common/virtual_authenticator/virtual_authenticator'
 require 'selenium/webdriver/common/html5/shared_web_storage'
 require 'selenium/webdriver/common/html5/local_storage'
 require 'selenium/webdriver/common/html5/session_storage'
-require 'selenium/webdriver/common/driver_extensions/takes_screenshot'
-require 'selenium/webdriver/common/driver_extensions/rotatable'
 require 'selenium/webdriver/common/driver_extensions/has_web_storage'
 require 'selenium/webdriver/common/driver_extensions/downloads_files'
 require 'selenium/webdriver/common/driver_extensions/has_location'
 require 'selenium/webdriver/common/driver_extensions/has_session_id'
-require 'selenium/webdriver/common/driver_extensions/has_touch_screen'
-require 'selenium/webdriver/common/driver_extensions/has_remote_status'
 require 'selenium/webdriver/common/driver_extensions/has_network_conditions'
 require 'selenium/webdriver/common/driver_extensions/has_network_connection'
+require 'selenium/webdriver/common/driver_extensions/has_network_interception'
+require 'selenium/webdriver/common/driver_extensions/has_apple_permissions'
 require 'selenium/webdriver/common/driver_extensions/has_permissions'
 require 'selenium/webdriver/common/driver_extensions/has_debugger'
+require 'selenium/webdriver/common/driver_extensions/has_context'
+require 'selenium/webdriver/common/driver_extensions/prints_page'
 require 'selenium/webdriver/common/driver_extensions/uploads_files'
+require 'selenium/webdriver/common/driver_extensions/full_page_screenshot'
 require 'selenium/webdriver/common/driver_extensions/has_addons'
-require 'selenium/webdriver/common/interactions/interactions'
-require 'selenium/webdriver/common/interactions/input_device'
-require 'selenium/webdriver/common/interactions/interaction'
-require 'selenium/webdriver/common/interactions/none_input'
-require 'selenium/webdriver/common/interactions/key_input'
-require 'selenium/webdriver/common/interactions/pointer_input'
+require 'selenium/webdriver/common/driver_extensions/has_bidi'
+require 'selenium/webdriver/common/driver_extensions/has_devtools'
+require 'selenium/webdriver/common/driver_extensions/has_authentication'
+require 'selenium/webdriver/common/driver_extensions/has_logs'
+require 'selenium/webdriver/common/driver_extensions/has_log_events'
+require 'selenium/webdriver/common/driver_extensions/has_pinned_scripts'
+require 'selenium/webdriver/common/driver_extensions/has_cdp'
+require 'selenium/webdriver/common/driver_extensions/has_casting'
+require 'selenium/webdriver/common/driver_extensions/has_launching'
 require 'selenium/webdriver/common/keys'
-require 'selenium/webdriver/common/bridge_helper'
 require 'selenium/webdriver/common/profile_helper'
 require 'selenium/webdriver/common/options'
+require 'selenium/webdriver/common/takes_screenshot'
 require 'selenium/webdriver/common/driver'
 require 'selenium/webdriver/common/element'
+require 'selenium/webdriver/common/shadow_root'
+require 'selenium/webdriver/common/websocket_connection'
