@@ -66,8 +66,8 @@ module Selenium
       }.freeze
 
       if Platform.jruby?
-        # we use a plain TCPSocket here since JRuby has issues select()ing on a connecting socket
-        # see http://jira.codehaus.org/browse/JRUBY-5165
+        # we use a plain TCPSocket here since JRuby has issues closing socket
+        # see https://github.com/jruby/jruby/issues/5709
         def listening?
           TCPSocket.new(@host, @port).close
           true
@@ -99,7 +99,7 @@ module Selenium
       end
 
       def socket_writable?(sock)
-        IO.select(nil, [sock], nil, CONNECT_TIMEOUT)
+        sock.wait_writable(CONNECT_TIMEOUT)
       end
 
       def conn_completed?(sock)
