@@ -17,6 +17,8 @@
 # specific language governing permissions and limitations
 # under the License.
 
+require 'selenium/webdriver/chrome/driver'
+
 module Selenium
   module WebDriver
     module Edge
@@ -26,40 +28,16 @@ module Selenium
       # @api private
       #
 
-      class Driver < WebDriver::Driver
-        include DriverExtensions::TakesScreenshot
-
-        def initialize(opts = {})
-          opts[:desired_capabilities] ||= Remote::Capabilities.edge
-
-          opts[:url] ||= service_url(opts)
-
-          listener = opts.delete(:listener)
-
-          # Edge is mostly using W3C dialect, but a request to
-          # create session responds with OSS-like body,
-          # so we need to force W3C implementation.
-          desired_capabilities = opts.delete(:desired_capabilities)
-          bridge = Remote::Bridge.new(opts)
-          capabilities = bridge.create_session(desired_capabilities)
-
-          WebDriver.logger.info 'Forcing W3C dialect.'
-          @bridge = Remote::W3C::Bridge.new(capabilities, bridge.session_id, **opts)
-          @bridge.extend Edge::Bridge
-
-          super(@bridge, listener: listener)
-        end
-
+      class Driver < Selenium::WebDriver::Chrome::Driver
         def browser
           :edge
         end
 
-        def quit
-          super
-        ensure
-          @service&.stop
-        end
+        private
 
+        def devtools_address
+          "http://#{capabilities['ms:edgeOptions']['debuggerAddress']}"
+        end
       end # Driver
     end # Edge
   end # WebDriver
