@@ -17,25 +17,12 @@
 # specific language governing permissions and limitations
 # under the License.
 
-require 'selenium/webdriver/ie/driver'
-require 'selenium/webdriver/ie/options'
-
 module Selenium
   module WebDriver
     module IE
-      def self.driver_path=(path)
-        WebDriver.logger.deprecate 'Selenium::WebDriver::IE#driver_path=',
-                                   'Selenium::WebDriver::IE::Service#driver_path='
-        Selenium::WebDriver::IE::Service.driver_path = path
-      end
-
-      def self.driver_path
-        WebDriver.logger.deprecate 'Selenium::WebDriver::IE#driver_path',
-                                   'Selenium::WebDriver::IE::Service#driver_path'
-        Selenium::WebDriver::IE::Service.driver_path
-      end
+      autoload :Driver, 'selenium/webdriver/ie/driver'
+      autoload :Options, 'selenium/webdriver/ie/options'
+      autoload :Service, 'selenium/webdriver/ie/service'
     end # IE
   end # WebDriver
 end # Selenium
-
-require 'selenium/webdriver/ie/service'
