@@ -27,41 +27,13 @@ module Selenium
       #
 
       class Driver < WebDriver::Driver
-        include DriverExtensions::HasDebugger
-        include DriverExtensions::HasPermissions
-        include DriverExtensions::TakesScreenshot
-
-        def initialize(opts = {})
-          opts[:desired_capabilities] = create_capabilities(opts)
-
-          opts[:url] ||= service_url(opts)
-
-          listener = opts.delete(:listener)
-          @bridge = Remote::Bridge.handshake(**opts)
-          @bridge.extend Bridge
-
-          super(@bridge, listener: listener)
-        end
+        EXTENSIONS = [DriverExtensions::HasDebugger,
+                      DriverExtensions::HasApplePermissions,
+                      DriverExtensions::HasWebStorage].freeze
 
         def browser
           :safari
         end
-
-        def quit
-          super
-        ensure
-          @service&.stop
-        end
-
-        private
-
-        def create_capabilities(opts = {})
-          caps = opts.delete(:desired_capabilities) { Remote::Capabilities.safari }
-          options = opts.delete(:options) { Options.new }
-          caps.merge!(options.as_json)
-          caps
-        end
-
       end # Driver
     end # Safari
   end # WebDriver
