@@ -31,7 +31,7 @@ module Selenium
           raise ArgumentError, "unexpected tag name #{tag_name.inspect}" unless tag_name.casecmp('select').zero?
 
           @element = element
-          @multi = ![nil, 'false'].include?(element.attribute(:multiple))
+          @multi = ![nil, 'false'].include?(element.dom_attribute(:multiple))
         end
 
         #
@@ -242,7 +242,7 @@ module Selenium
           xpath = ".//option[normalize-space(.) = #{Escaper.escape text}]"
           opts = @element.find_elements(xpath: xpath)
 
-          return opts unless opts.empty? && text =~ /\s+/
+          return opts unless opts.empty? && /\s+/.match?(text)
 
           longest_word = text.split(/\s+/).max_by(&:length)
           if longest_word.empty?
@@ -258,7 +258,7 @@ module Selenium
         end
 
         def find_by_index(index)
-          options.select { |option| option.attribute(:index) == index.to_s }
+          options.select { |option| option.property(:index) == index }
         end
 
         def find_by_value(value)
